@@ -4,6 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "testhelper.h"
+
+#include <applicationcontroller.h>
 #include <reservationmanager.h>
 #include <pkpassmanager.h>
 
@@ -21,30 +24,6 @@ using namespace KItinerary;
 class ReservationManagerTest : public QObject
 {
     Q_OBJECT
-private:
-    void clearReservations(ReservationManager *mgr)
-    {
-        const auto batches = mgr->batches(); // copy, as this is getting modified in the process
-        for (const auto &id : batches) {
-            mgr->removeBatch(id);
-        }
-        QCOMPARE(mgr->batches().size(), 0);
-    }
-
-    void clearPasses(PkPassManager *mgr)
-    {
-        for (const auto &id : mgr->passes()) {
-            mgr->removePass(id);
-        }
-    }
-
-    QByteArray readFile(const QString &fn)
-    {
-        QFile f(fn);
-        f.open(QFile::ReadOnly);
-        return f.readAll();
-    }
-
 private Q_SLOTS:
     void initTestCase()
     {
@@ -54,7 +33,7 @@ private Q_SLOTS:
     void testOperations()
     {
         ReservationManager mgr;
-        clearReservations(&mgr);
+        Test::clearAll(&mgr);
 
         QSignalSpy addSpy(&mgr, &ReservationManager::reservationAdded);
         QVERIFY(addSpy.isValid());
@@ -64,7 +43,9 @@ private Q_SLOTS:
         QVERIFY(rmSpy.isValid());
 
         QVERIFY(mgr.batches().empty());
-        mgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&mgr);
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/4U8465-v1.json")));
 
         auto res = mgr.batches();
         QCOMPARE(res.size(), 1);
@@ -76,7 +57,7 @@ private Q_SLOTS:
         QVERIFY(updateSpy.isEmpty());
         QVERIFY(!mgr.reservation(resId).isNull());
 
-        mgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/4U8465-v2.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/4U8465-v2.json")));
         QCOMPARE(addSpy.size(), 1);
         QCOMPARE(updateSpy.size(), 1);
         QCOMPARE(mgr.batches().size(), 1);
@@ -91,7 +72,7 @@ private Q_SLOTS:
         QVERIFY(mgr.batches().empty());
         QVERIFY(mgr.reservation(resId).isNull());
 
-        clearReservations(&mgr);
+        Test::clearAll(&mgr);
         auto attraction = KItinerary::TouristAttraction();
         attraction.setName(QStringLiteral("Sky Tree"));
         auto visit = KItinerary::TouristAttractionVisit();
@@ -109,11 +90,14 @@ private Q_SLOTS:
     void testPkPassChanges()
     {
         PkPassManager passMgr;
-        clearPasses(&passMgr);
+        Test::clearAll(&passMgr);
 
         ReservationManager mgr;
-        mgr.setPkPassManager(&passMgr);
-        clearReservations(&mgr);
+        Test::clearAll(&mgr);
+
+        ApplicationController ctrl;
+        ctrl.setPkPassManager(&passMgr);
+        ctrl.setReservationManager(&mgr);
 
         QSignalSpy addSpy(&mgr, &ReservationManager::reservationAdded);
         QVERIFY(addSpy.isValid());
@@ -135,10 +119,12 @@ private Q_SLOTS:
     void testBatchPersistence()
     {
         ReservationManager mgr;
-        clearReservations(&mgr);
+        Test::clearAll(&mgr);
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&mgr);
 
         QCOMPARE(mgr.batches().size(), 0);
-        mgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
         QCOMPARE(mgr.batches().size(), 2);
 
         const auto batchId = mgr.batches()[0];
@@ -167,7 +153,7 @@ private Q_SLOTS:
     void testBatchOperations()
     {
         ReservationManager mgr;
-        clearReservations(&mgr);
+        Test::clearAll(&mgr);
         QCOMPARE(mgr.batches().size(), 0);
 
         QSignalSpy batchAddSpy(&mgr, &ReservationManager::batchAdded);
@@ -176,7 +162,9 @@ private Q_SLOTS:
         QSignalSpy batchRenameSpy(&mgr, &ReservationManager::batchRenamed);
         QSignalSpy batchRemovedSpy(&mgr, &ReservationManager::batchRemoved);
 
-        mgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&mgr);
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/data/google-multi-passenger-flight.json")));
         QCOMPARE(batchAddSpy.size(), 2);
         QCOMPARE(batchChangeSpy.size(), 2);
         QCOMPARE(batchRenameSpy.size(), 0);
@@ -331,9 +319,11 @@ private Q_SLOTS:
     void testCancellation()
     {
         ReservationManager mgr;
-        clearReservations(&mgr);
+        Test::clearAll(&mgr);
+        ApplicationController ctrl;
+        ctrl.setReservationManager(&mgr);
         QCOMPARE(mgr.batches().size(), 0);
-        mgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017.json")));
         QCOMPARE(mgr.batches().size(), 11);
 
         auto res = mgr.reservation(mgr.batches().at(0));
@@ -348,7 +338,7 @@ private Q_SLOTS:
         QSignalSpy batchRenameSpy(&mgr, &ReservationManager::batchRenamed);
         QSignalSpy batchRemovedSpy(&mgr, &ReservationManager::batchRemoved);
 
-        mgr.importReservation(readFile(QLatin1String(SOURCE_DIR "/../tests/randa2017-flight-cancellation.json")));
+        ctrl.importFromUrl(QUrl::fromLocalFile(QLatin1String(SOURCE_DIR "/../tests/randa2017-flight-cancellation.json")));
         QCOMPARE(mgr.batches().size(), 11);
         QCOMPARE(batchAddSpy.size(), 0);
         QCOMPARE(batchChangeSpy.size(), 0);
