@@ -9,7 +9,10 @@
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/Place>
 
+#include <kcontacts_version.h>
 #include <KContacts/Address>
+
+#include <KCountry>
 #include <KFormat>
 #include <KLocalizedString>
 
@@ -33,26 +36,6 @@ using namespace KAndroidExtras;
 
 using namespace KItinerary;
 
-QString Localizer::countryName(const QString& isoCode) const
-{
-    return KContacts::Address::ISOtoCountry(isoCode);
-}
-
-QString Localizer::countryFlag(const QString& isoCode) const
-{
-    if (isoCode.size() != 2) {
-        return {};
-    }
-
-    QString flag;
-    char flagA[] = "\xF0\x9F\x87\xA6";
-    flagA[3] = 0xA6 + (isoCode[0].toLatin1() - 'A');
-    flag += QString::fromUtf8(flagA);
-    flagA[3] = 0xA6 + (isoCode[1].toLatin1() - 'A');
-    flag += QString::fromUtf8(flagA);
-    return flag;
-}
-
 static QString readFromGadget(const QMetaObject *mo, const QVariant &gadget, const char *propName)
 {
     const auto propIdx = mo->indexOfProperty(propName);
@@ -75,19 +58,23 @@ QString Localizer::formatAddress(const QVariant &obj) const
         address.setPostalCode(a.postalCode());
         address.setLocality(a.addressLocality());
         address.setRegion(a.addressRegion());
-        address.setCountry(KContacts::Address::ISOtoCountry(a.addressCountry()));
+        address.setCountry(KCountry::fromAlpha2(a.addressCountry()).name());
     } else if (std::strcmp(obj.typeName(), "KOSMIndoorMap::OSMAddress") == 0) {
         const auto mo = QMetaType::metaObjectForType(obj.userType());
         address.setStreet(readFromGadget(mo, obj, "street") + QLatin1Char(' ') + readFromGadget(mo, obj, "houseNumber"));
         address.setPostalCode(readFromGadget(mo, obj, "postalCode"));
         address.setLocality(readFromGadget(mo, obj, "city"));
         address.setRegion(readFromGadget(mo, obj, "state"));
-        address.setCountry(KContacts::Address::ISOtoCountry(readFromGadget(mo, obj, "country")));
+        address.setCountry(KCountry::fromAlpha2(readFromGadget(mo, obj, "country")).name());
     } else {
         return {};
     }
 
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 92, 0)
     return address.formattedAddress().replace(QLatin1String("\n\n"), QLatin1String("\n")).trimmed();
+#else
+    return address.formatted(KContacts::AddressFormatStyle::MultiLineInternational);
+#endif
 }
 
 static bool needsTimeZone(const QDateTime &dt)
@@ -108,7 +95,7 @@ static QString tzAbbreviation(const QDateTime &dt)
     // the QTimeZone backend implementation on Android isn't as complete as the desktop ones, so we need to do this ourselves here
     // eventually, this should be upstreamed to Qt
     auto abbr = QAndroidJniObject::callStaticObjectMethod("org/kde/itinerary/QTimeZone", "abbreviation",
-                    Jni::signature<java::lang::String(java::lang::String, long, java::util::Locale, bool)>(),
+                    Jni::signature<java::lang::String(java::lang::String, jlong, java::util::Locale, bool)>(),
                     QAndroidJniObject::fromString(QString::fromUtf8(tz.id())).object(), dt.toMSecsSinceEpoch(),
                     KAndroidExtras::Locale::current().object(), tz.isDaylightTime(dt)).toString();
 
@@ -142,7 +129,7 @@ QString Localizer::formatDate(const QVariant &obj, const QString &propertyName)
     }
 
     if (dt.year() <= 1900) { // no year specified
-        return dt.toString(QStringLiteral("dd MMMM")); // TODO i18n in master
+        return dt.toString(i18nc("day-only date format", "dd MMMM"));
     }
     return QLocale().toString(dt, QLocale::ShortFormat);
 }
